@@ -4,11 +4,7 @@ from .pattern import HamelnPatternManager
 
 from .rewriter.conv_conv_concat_bn_leakyrelu_rewriter import conv_conv_concat_bn_leakyrelu
 
-
 HPM = HamelnPatternManager()
 
-
-HPM.register_pattern(
-    pattern_name="conv_conv_concat_bn_leakyrelu",
-    pattern=conv_conv_concat_bn_leakyrelu
-)
+HPM.register_pattern(pattern_name="conv_conv_concat_bn_leakyrelu",
+                     pattern=conv_conv_concat_bn_leakyrelu)
